/*!
* Copyright Adaptavist 2023 (c) All rights reserved
*/
import { Headers, Response, BaseApiCore, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { CustomError } from './common';
import { CommonError, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { GetSObjectBasicInformationRequest, GetSObjectBasicInformationResponseOK } from './types/sObject';
import { DeleteSObjectRowRecordRequest, DeleteSObjectRowRecordResponseOK, GetSObjectRowRecordRequest, GetSObjectRowRecordResponseOK, UpdateSObjectRowRecordRequest, UpdateSObjectRowRecordResponseOK } from './types/sObject/row';
export interface SalesforceApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class SalesforceApiCore extends BaseApiCore {
    private options?;
    sObject: SObjectGroup;
    All: AllGroup;
    constructor(options?: SalesforceApiCoreOptions);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private sObject;
    constructor(sObject: SObjectGroup);
    /**
     * Gets basic metadata for a specified object, including some object properties, recent items, and URIs for other resources related to the object.
     * Alternative usage: sObject.getBasicInformation
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.242.0.api_rest.meta/api_rest/resources_sobject_basic_info_get.htm
     * @param options Request options.
    */
    getSObjectBasicInformation<T = GetSObjectBasicInformationResponseOK>(options?: GetSObjectBasicInformationRequest): Promise<GetSObjectBasicInformationResponseOK | T>;
    /**
     * Gets a record based on the specified object and record ID.
     * Alternative usage: sObject.Rows.getRecord
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.242.0.api_rest.meta/api_rest/resources_sobject_retrieve_get.htm
     * @param options Request options.
    */
    getSObjectRowRecord<T = GetSObjectRowRecordResponseOK>(options?: GetSObjectRowRecordRequest): Promise<GetSObjectRowRecordResponseOK | T>;
    /**
     * Updates a record based on the specified object and record ID. Field values provided in the request body replace the existing values in the record.
     * Alternative usage: sObject.Rows.updateRecord
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_patch.htm
     * @param options Request options.
    */
    updateSObjectRowRecord<T = UpdateSObjectRowRecordResponseOK>(options?: UpdateSObjectRowRecordRequest): Promise<UpdateSObjectRowRecordResponseOK | T>;
    /**
     * Deletes records based on the specified object and record ID.
     * Alternative usage: sObject.Rows.deleteRecord
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_delete.htm
     * @param options Request options.
    */
    deleteSObjectRowRecord<T = UpdateSObjectRowRecordResponseOK>(options?: UpdateSObjectRowRecordRequest): Promise<UpdateSObjectRowRecordResponseOK | T>;
}
declare class SObjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Row: SObjectRowGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets basic metadata for a specified object, including some object properties, recent items, and URIs for other resources related to the object.
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.242.0.api_rest.meta/api_rest/resources_sobject_basic_info_get.htm
     * @param options Request options.
     */
    getBasicInformation<T = GetSObjectBasicInformationResponseOK>(options?: GetSObjectBasicInformationRequest): Promise<GetSObjectBasicInformationResponseOK | T>;
}
declare class SObjectRowGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Gets a record based on the specified object and record ID.
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.242.0.api_rest.meta/api_rest/resources_sobject_retrieve_get.htm
     * @param options Request options.
     */
    getRecord<T = GetSObjectRowRecordResponseOK>(options?: GetSObjectRowRecordRequest): Promise<GetSObjectRowRecordResponseOK | T>;
    /**
     * Updates a record based on the specified object and record ID. Field values provided in the request body replace the existing values in the record.
     * Documentation: https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_patch.htm
     * @param options Request options.
     */
    updateRecord<T = UpdateSObjectRowRecordResponseOK>(options?: UpdateSObjectRowRecordRequest): Promise<UpdateSObjectRowRecordResponseOK | T>;
    /**
    * Deletes records based on the specified object and record ID.
    * Documentation: https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_delete.htm
    * @param options Request options.
    */
    deleteRecord<T = DeleteSObjectRowRecordResponseOK>(options?: DeleteSObjectRowRecordRequest): Promise<DeleteSObjectRowRecordResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map